from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage
import win32more.Windows.Storage.Pickers.Provider
import win32more.Windows.Win32.System.WinRT
class AddFileResult(Enum, Int32):
    Added = 0
    AlreadyAdded = 1
    NotAllowed = 2
    Unavailable = 3
class FileOpenPickerUI(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI
    _classid_ = 'Windows.Storage.Pickers.Provider.FileOpenPickerUI'
    @winrt_mixinmethod
    def AddFile(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI, id: WinRT_String, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Storage.Pickers.Provider.AddFileResult: ...
    @winrt_mixinmethod
    def RemoveFile(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI, id: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def ContainsFile(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI, id: WinRT_String) -> Boolean: ...
    @winrt_mixinmethod
    def CanAddFile(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI, file: win32more.Windows.Storage.IStorageFile) -> Boolean: ...
    @winrt_mixinmethod
    def get_AllowedFileTypes(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_SelectionMode(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI) -> win32more.Windows.Storage.Pickers.Provider.FileSelectionMode: ...
    @winrt_mixinmethod
    def get_SettingsIdentifier(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def add_FileRemoved(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.Pickers.Provider.FileOpenPickerUI, win32more.Windows.Storage.Pickers.Provider.FileRemovedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FileRemoved(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_Closing(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.Pickers.Provider.FileOpenPickerUI, win32more.Windows.Storage.Pickers.Provider.PickerClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Closing(self: win32more.Windows.Storage.Pickers.Provider.IFileOpenPickerUI, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AllowedFileTypes = property(get_AllowedFileTypes, None)
    SelectionMode = property(get_SelectionMode, None)
    SettingsIdentifier = property(get_SettingsIdentifier, None)
    Title = property(get_Title, put_Title)
    FileRemoved = event()
    Closing = event()
class FileRemovedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.Provider.IFileRemovedEventArgs
    _classid_ = 'Windows.Storage.Pickers.Provider.FileRemovedEventArgs'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Storage.Pickers.Provider.IFileRemovedEventArgs) -> WinRT_String: ...
    Id = property(get_Id, None)
class FileSavePickerUI(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI
    _classid_ = 'Windows.Storage.Pickers.Provider.FileSavePickerUI'
    @winrt_mixinmethod
    def get_Title(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Title(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_AllowedFileTypes(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_mixinmethod
    def get_SettingsIdentifier(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FileName(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI) -> WinRT_String: ...
    @winrt_mixinmethod
    def TrySetFileName(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI, value: WinRT_String) -> win32more.Windows.Storage.Pickers.Provider.SetFileNameResult: ...
    @winrt_mixinmethod
    def add_FileNameChanged(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.Pickers.Provider.FileSavePickerUI, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FileNameChanged(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TargetFileRequested(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.Pickers.Provider.FileSavePickerUI, win32more.Windows.Storage.Pickers.Provider.TargetFileRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TargetFileRequested(self: win32more.Windows.Storage.Pickers.Provider.IFileSavePickerUI, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AllowedFileTypes = property(get_AllowedFileTypes, None)
    FileName = property(get_FileName, None)
    SettingsIdentifier = property(get_SettingsIdentifier, None)
    Title = property(get_Title, put_Title)
    FileNameChanged = event()
    TargetFileRequested = event()
class FileSelectionMode(Enum, Int32):
    Single = 0
    Multiple = 1
class IFileOpenPickerUI(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.Provider.IFileOpenPickerUI'
    _iid_ = Guid('{dda45a10-f9d4-40c4-8af5-c5b6b5a61d1d}')
    @winrt_commethod(6)
    def AddFile(self, id: WinRT_String, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Storage.Pickers.Provider.AddFileResult: ...
    @winrt_commethod(7)
    def RemoveFile(self, id: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def ContainsFile(self, id: WinRT_String) -> Boolean: ...
    @winrt_commethod(9)
    def CanAddFile(self, file: win32more.Windows.Storage.IStorageFile) -> Boolean: ...
    @winrt_commethod(10)
    def get_AllowedFileTypes(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(11)
    def get_SelectionMode(self) -> win32more.Windows.Storage.Pickers.Provider.FileSelectionMode: ...
    @winrt_commethod(12)
    def get_SettingsIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(14)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(15)
    def add_FileRemoved(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.Pickers.Provider.FileOpenPickerUI, win32more.Windows.Storage.Pickers.Provider.FileRemovedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_FileRemoved(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_Closing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.Pickers.Provider.FileOpenPickerUI, win32more.Windows.Storage.Pickers.Provider.PickerClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_Closing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AllowedFileTypes = property(get_AllowedFileTypes, None)
    SelectionMode = property(get_SelectionMode, None)
    SettingsIdentifier = property(get_SettingsIdentifier, None)
    Title = property(get_Title, put_Title)
    FileRemoved = event()
    Closing = event()
class IFileRemovedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.Provider.IFileRemovedEventArgs'
    _iid_ = Guid('{13043da7-7fca-4c2b-9eca-6890f9f00185}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    Id = property(get_Id, None)
class IFileSavePickerUI(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.Provider.IFileSavePickerUI'
    _iid_ = Guid('{9656c1e7-3e56-43cc-8a39-33c73d9d542b}')
    @winrt_commethod(6)
    def get_Title(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Title(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_AllowedFileTypes(self) -> win32more.Windows.Foundation.Collections.IVectorView[WinRT_String]: ...
    @winrt_commethod(9)
    def get_SettingsIdentifier(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_FileName(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def TrySetFileName(self, value: WinRT_String) -> win32more.Windows.Storage.Pickers.Provider.SetFileNameResult: ...
    @winrt_commethod(12)
    def add_FileNameChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.Pickers.Provider.FileSavePickerUI, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_FileNameChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_TargetFileRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.Pickers.Provider.FileSavePickerUI, win32more.Windows.Storage.Pickers.Provider.TargetFileRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_TargetFileRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    AllowedFileTypes = property(get_AllowedFileTypes, None)
    FileName = property(get_FileName, None)
    SettingsIdentifier = property(get_SettingsIdentifier, None)
    Title = property(get_Title, put_Title)
    FileNameChanged = event()
    TargetFileRequested = event()
class IPickerClosingDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.Provider.IPickerClosingDeferral'
    _iid_ = Guid('{7af7f71e-1a67-4a31-ae80-e907708a619b}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class IPickerClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.Provider.IPickerClosingEventArgs'
    _iid_ = Guid('{7e59f224-b332-4f12-8b9f-a8c2f06b32cd}')
    @winrt_commethod(6)
    def get_ClosingOperation(self) -> win32more.Windows.Storage.Pickers.Provider.PickerClosingOperation: ...
    @winrt_commethod(7)
    def get_IsCanceled(self) -> Boolean: ...
    ClosingOperation = property(get_ClosingOperation, None)
    IsCanceled = property(get_IsCanceled, None)
class IPickerClosingOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.Provider.IPickerClosingOperation'
    _iid_ = Guid('{4ce9fb84-beee-4e39-a773-fc5f0eae328d}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Storage.Pickers.Provider.PickerClosingDeferral: ...
    @winrt_commethod(7)
    def get_Deadline(self) -> win32more.Windows.Foundation.DateTime: ...
    Deadline = property(get_Deadline, None)
class ITargetFileRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.Provider.ITargetFileRequest'
    _iid_ = Guid('{42bd3355-7f88-478b-8e81-690b20340678}')
    @winrt_commethod(6)
    def get_TargetFile(self) -> win32more.Windows.Storage.IStorageFile: ...
    @winrt_commethod(7)
    def put_TargetFile(self, value: win32more.Windows.Storage.IStorageFile) -> Void: ...
    @winrt_commethod(8)
    def GetDeferral(self) -> win32more.Windows.Storage.Pickers.Provider.TargetFileRequestDeferral: ...
    TargetFile = property(get_TargetFile, put_TargetFile)
class ITargetFileRequestDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.Provider.ITargetFileRequestDeferral'
    _iid_ = Guid('{4aee9d91-bf15-4da9-95f6-f6b7d558225b}')
    @winrt_commethod(6)
    def Complete(self) -> Void: ...
class ITargetFileRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.Pickers.Provider.ITargetFileRequestedEventArgs'
    _iid_ = Guid('{b163dbc1-1b51-4c89-a591-0fd40b3c57c9}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.Storage.Pickers.Provider.TargetFileRequest: ...
    Request = property(get_Request, None)
class PickerClosingDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.Provider.IPickerClosingDeferral
    _classid_ = 'Windows.Storage.Pickers.Provider.PickerClosingDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Windows.Storage.Pickers.Provider.IPickerClosingDeferral) -> Void: ...
class PickerClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.Provider.IPickerClosingEventArgs
    _classid_ = 'Windows.Storage.Pickers.Provider.PickerClosingEventArgs'
    @winrt_mixinmethod
    def get_ClosingOperation(self: win32more.Windows.Storage.Pickers.Provider.IPickerClosingEventArgs) -> win32more.Windows.Storage.Pickers.Provider.PickerClosingOperation: ...
    @winrt_mixinmethod
    def get_IsCanceled(self: win32more.Windows.Storage.Pickers.Provider.IPickerClosingEventArgs) -> Boolean: ...
    ClosingOperation = property(get_ClosingOperation, None)
    IsCanceled = property(get_IsCanceled, None)
class PickerClosingOperation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.Provider.IPickerClosingOperation
    _classid_ = 'Windows.Storage.Pickers.Provider.PickerClosingOperation'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Storage.Pickers.Provider.IPickerClosingOperation) -> win32more.Windows.Storage.Pickers.Provider.PickerClosingDeferral: ...
    @winrt_mixinmethod
    def get_Deadline(self: win32more.Windows.Storage.Pickers.Provider.IPickerClosingOperation) -> win32more.Windows.Foundation.DateTime: ...
    Deadline = property(get_Deadline, None)
class SetFileNameResult(Enum, Int32):
    Succeeded = 0
    NotAllowed = 1
    Unavailable = 2
class TargetFileRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.Provider.ITargetFileRequest
    _classid_ = 'Windows.Storage.Pickers.Provider.TargetFileRequest'
    @winrt_mixinmethod
    def get_TargetFile(self: win32more.Windows.Storage.Pickers.Provider.ITargetFileRequest) -> win32more.Windows.Storage.IStorageFile: ...
    @winrt_mixinmethod
    def put_TargetFile(self: win32more.Windows.Storage.Pickers.Provider.ITargetFileRequest, value: win32more.Windows.Storage.IStorageFile) -> Void: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.Storage.Pickers.Provider.ITargetFileRequest) -> win32more.Windows.Storage.Pickers.Provider.TargetFileRequestDeferral: ...
    TargetFile = property(get_TargetFile, put_TargetFile)
class TargetFileRequestDeferral(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.Provider.ITargetFileRequestDeferral
    _classid_ = 'Windows.Storage.Pickers.Provider.TargetFileRequestDeferral'
    @winrt_mixinmethod
    def Complete(self: win32more.Windows.Storage.Pickers.Provider.ITargetFileRequestDeferral) -> Void: ...
class TargetFileRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.Pickers.Provider.ITargetFileRequestedEventArgs
    _classid_ = 'Windows.Storage.Pickers.Provider.TargetFileRequestedEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.Storage.Pickers.Provider.ITargetFileRequestedEventArgs) -> win32more.Windows.Storage.Pickers.Provider.TargetFileRequest: ...
    Request = property(get_Request, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel
import win32more.Windows.ApplicationModel.PackageExtensions
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage
import win32more.Windows.Win32.System.WinRT
class IPackageExtension(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.IPackageExtension'
    _iid_ = Guid('{da70c957-7ead-5c3b-9cf0-cc43faf474b4}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Description(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Package(self) -> win32more.Windows.ApplicationModel.Package: ...
    @winrt_commethod(10)
    def GetExtensionProperties(self) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_commethod(11)
    def GetExtensionPropertiesAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IPropertySet]: ...
    @winrt_commethod(12)
    def GetPublicPath(self) -> WinRT_String: ...
    @winrt_commethod(13)
    def GetPublicFolder(self) -> win32more.Windows.Storage.StorageFolder: ...
    @winrt_commethod(14)
    def GetPublicFolderAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    Description = property(get_Description, None)
    DisplayName = property(get_DisplayName, None)
    Id = property(get_Id, None)
    Package = property(get_Package, None)
class IPackageExtensionCatalog(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog'
    _iid_ = Guid('{0879dfe6-ac30-58b2-97f9-480b07e75bfa}')
    @winrt_commethod(6)
    def FindAll(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtension]: ...
    @winrt_commethod(7)
    def FindAllAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtension]]: ...
    @winrt_commethod(8)
    def RequestRemovePackageAsync(self, packageFullName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_commethod(9)
    def add_PackageInstalled(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageInstalledEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_PackageInstalled(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def add_PackageUpdating(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageUpdatingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_PackageUpdating(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def add_PackageUpdated(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageUpdatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(14)
    def remove_PackageUpdated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(15)
    def add_PackageUninstalling(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageUninstallingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(16)
    def remove_PackageUninstalling(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(17)
    def add_PackageStatusChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageStatusChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(18)
    def remove_PackageStatusChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    PackageInstalled = event()
    PackageUpdating = event()
    PackageUpdated = event()
    PackageUninstalling = event()
    PackageStatusChanged = event()
class IPackageExtensionCatalogStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalogStatics'
    _iid_ = Guid('{9588ece4-3183-5684-9e5f-27759733ddfe}')
    @winrt_commethod(6)
    def Open(self, packageExtensionName: WinRT_String) -> win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog: ...
class IPackageExtensionPackageInstalledEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageInstalledEventArgs'
    _iid_ = Guid('{3c9b0067-083c-5fe3-bdfb-9feb156b4118}')
    @winrt_commethod(6)
    def get_PackageExtensionName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Package(self) -> win32more.Windows.ApplicationModel.Package: ...
    @winrt_commethod(8)
    def get_Extensions(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtension]: ...
    Extensions = property(get_Extensions, None)
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)
class IPackageExtensionPackageStatusChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageStatusChangedEventArgs'
    _iid_ = Guid('{b8fee20a-680d-5942-876c-5de12df1083c}')
    @winrt_commethod(6)
    def get_PackageExtensionName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Package(self) -> win32more.Windows.ApplicationModel.Package: ...
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)
class IPackageExtensionPackageUninstallingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUninstallingEventArgs'
    _iid_ = Guid('{3b8e9cb7-c539-554d-bb33-a84c0bfa3f50}')
    @winrt_commethod(6)
    def get_PackageExtensionName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Package(self) -> win32more.Windows.ApplicationModel.Package: ...
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)
class IPackageExtensionPackageUpdatedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUpdatedEventArgs'
    _iid_ = Guid('{fdc31add-16a7-509d-8bc4-fde22e856d2d}')
    @winrt_commethod(6)
    def get_PackageExtensionName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Package(self) -> win32more.Windows.ApplicationModel.Package: ...
    @winrt_commethod(8)
    def get_Extensions(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtension]: ...
    Extensions = property(get_Extensions, None)
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)
class IPackageExtensionPackageUpdatingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUpdatingEventArgs'
    _iid_ = Guid('{27ae2ce1-a1d3-532e-8e7e-8b43782fce09}')
    @winrt_commethod(6)
    def get_PackageExtensionName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Package(self) -> win32more.Windows.ApplicationModel.Package: ...
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)
class PackageExtension(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.PackageExtension'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Package(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension) -> win32more.Windows.ApplicationModel.Package: ...
    @winrt_mixinmethod
    def GetExtensionProperties(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_mixinmethod
    def GetExtensionPropertiesAsync(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IPropertySet]: ...
    @winrt_mixinmethod
    def GetPublicPath(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetPublicFolder(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension) -> win32more.Windows.Storage.StorageFolder: ...
    @winrt_mixinmethod
    def GetPublicFolderAsync(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtension) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    Description = property(get_Description, None)
    DisplayName = property(get_DisplayName, None)
    Id = property(get_Id, None)
    Package = property(get_Package, None)
class PackageExtensionCatalog(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog'
    @winrt_mixinmethod
    def FindAll(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtension]: ...
    @winrt_mixinmethod
    def FindAllAsync(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtension]]: ...
    @winrt_mixinmethod
    def RequestRemovePackageAsync(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, packageFullName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def add_PackageInstalled(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageInstalledEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PackageInstalled(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PackageUpdating(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageUpdatingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PackageUpdating(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PackageUpdated(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageUpdatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PackageUpdated(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PackageUninstalling(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageUninstallingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PackageUninstalling(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PackageStatusChanged(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog, win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageStatusChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PackageStatusChanged(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalog, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def Open(cls: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionCatalogStatics, packageExtensionName: WinRT_String) -> win32more.Windows.ApplicationModel.PackageExtensions.PackageExtensionCatalog: ...
    PackageInstalled = event()
    PackageUpdating = event()
    PackageUpdated = event()
    PackageUninstalling = event()
    PackageStatusChanged = event()
class PackageExtensionPackageInstalledEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageInstalledEventArgs
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageInstalledEventArgs'
    @winrt_mixinmethod
    def get_PackageExtensionName(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageInstalledEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Package(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageInstalledEventArgs) -> win32more.Windows.ApplicationModel.Package: ...
    @winrt_mixinmethod
    def get_Extensions(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageInstalledEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtension]: ...
    Extensions = property(get_Extensions, None)
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)
class PackageExtensionPackageStatusChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageStatusChangedEventArgs
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageStatusChangedEventArgs'
    @winrt_mixinmethod
    def get_PackageExtensionName(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageStatusChangedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Package(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageStatusChangedEventArgs) -> win32more.Windows.ApplicationModel.Package: ...
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)
class PackageExtensionPackageUninstallingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUninstallingEventArgs
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageUninstallingEventArgs'
    @winrt_mixinmethod
    def get_PackageExtensionName(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUninstallingEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Package(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUninstallingEventArgs) -> win32more.Windows.ApplicationModel.Package: ...
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)
class PackageExtensionPackageUpdatedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUpdatedEventArgs
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageUpdatedEventArgs'
    @winrt_mixinmethod
    def get_PackageExtensionName(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUpdatedEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Package(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUpdatedEventArgs) -> win32more.Windows.ApplicationModel.Package: ...
    @winrt_mixinmethod
    def get_Extensions(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUpdatedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.PackageExtensions.PackageExtension]: ...
    Extensions = property(get_Extensions, None)
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)
class PackageExtensionPackageUpdatingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUpdatingEventArgs
    _classid_ = 'Windows.ApplicationModel.PackageExtensions.PackageExtensionPackageUpdatingEventArgs'
    @winrt_mixinmethod
    def get_PackageExtensionName(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUpdatingEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Package(self: win32more.Windows.ApplicationModel.PackageExtensions.IPackageExtensionPackageUpdatingEventArgs) -> win32more.Windows.ApplicationModel.Package: ...
    Package = property(get_Package, None)
    PackageExtensionName = property(get_PackageExtensionName, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Security.Authorization.AppCapabilityAccess
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class AppCapability(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapability
    _classid_ = 'Windows.Security.Authorization.AppCapabilityAccess.AppCapability'
    @winrt_mixinmethod
    def get_CapabilityName(self: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapability) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapability) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def RequestAccessAsync(self: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapability) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus]: ...
    @winrt_mixinmethod
    def CheckAccess(self: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapability) -> win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus: ...
    @winrt_mixinmethod
    def add_AccessChanged(self: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapability, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapability, win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_AccessChanged(self: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapability, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_DisplayMessage(self: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapability2) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_DisplayMessage(self: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapability2, value: WinRT_String) -> Void: ...
    @winrt_classmethod
    def RequestAccessForCapabilitiesAsync(cls: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapabilityStatics, capabilityNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus]]: ...
    @winrt_classmethod
    def RequestAccessForCapabilitiesForUserAsync(cls: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapabilityStatics, user: win32more.Windows.System.User, capabilityNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus]]: ...
    @winrt_classmethod
    def Create(cls: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapabilityStatics, capabilityName: WinRT_String) -> win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapability: ...
    @winrt_classmethod
    def CreateWithProcessIdForUser(cls: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapabilityStatics, user: win32more.Windows.System.User, capabilityName: WinRT_String, pid: UInt32) -> win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapability: ...
    CapabilityName = property(get_CapabilityName, None)
    DisplayMessage = property(get_DisplayMessage, put_DisplayMessage)
    User = property(get_User, None)
    AccessChanged = event()
class AppCapabilityAccessChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Security.Authorization.AppCapabilityAccess.IAppCapabilityAccessChangedEventArgs
    _classid_ = 'Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessChangedEventArgs'
class AppCapabilityAccessStatus(Enum, Int32):
    DeniedBySystem = 0
    NotDeclaredByApp = 1
    DeniedByUser = 2
    UserPromptRequired = 3
    Allowed = 4
class IAppCapability(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authorization.AppCapabilityAccess.IAppCapability'
    _iid_ = Guid('{4c49d915-8a2a-4295-9437-2df7c396aff4}')
    @winrt_commethod(6)
    def get_CapabilityName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_User(self) -> win32more.Windows.System.User: ...
    @winrt_commethod(8)
    def RequestAccessAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus]: ...
    @winrt_commethod(9)
    def CheckAccess(self) -> win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus: ...
    @winrt_commethod(10)
    def add_AccessChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapability, win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_AccessChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CapabilityName = property(get_CapabilityName, None)
    User = property(get_User, None)
    AccessChanged = event()
class IAppCapability2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authorization.AppCapabilityAccess.IAppCapability2'
    _iid_ = Guid('{11c7ccb6-c74f-50a3-b960-88008767d939}')
    @winrt_commethod(6)
    def get_DisplayMessage(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_DisplayMessage(self, value: WinRT_String) -> Void: ...
    DisplayMessage = property(get_DisplayMessage, put_DisplayMessage)
class IAppCapabilityAccessChangedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authorization.AppCapabilityAccess.IAppCapabilityAccessChangedEventArgs'
    _iid_ = Guid('{0a578d15-bdd7-457e-8cca-6f53bd2e5944}')
class IAppCapabilityStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Security.Authorization.AppCapabilityAccess.IAppCapabilityStatics'
    _iid_ = Guid('{7c353e2a-46ee-44e5-af3d-6ad3fc49bd22}')
    @winrt_commethod(6)
    def RequestAccessForCapabilitiesAsync(self, capabilityNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus]]: ...
    @winrt_commethod(7)
    def RequestAccessForCapabilitiesForUserAsync(self, user: win32more.Windows.System.User, capabilityNames: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapabilityAccessStatus]]: ...
    @winrt_commethod(8)
    def Create(self, capabilityName: WinRT_String) -> win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapability: ...
    @winrt_commethod(9)
    def CreateWithProcessIdForUser(self, user: win32more.Windows.System.User, capabilityName: WinRT_String, pid: UInt32) -> win32more.Windows.Security.Authorization.AppCapabilityAccess.AppCapability: ...


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices
BUS1394_VIRTUAL_DEVICE_LIST_KEY: String = 'Virtual Device List'
BUS1394_LOCAL_HOST_INSTANCE_KEY: String = 'LOCAL HOST EUI64'
IOCTL_IEEE1394_API_REQUEST: UInt32 = 2229248
IEEE1394_API_ADD_VIRTUAL_DEVICE: UInt32 = 1
IEEE1394_API_REMOVE_VIRTUAL_DEVICE: UInt32 = 2
IEEE1394_API_DEVICE_ACCESS_TRANSFER: UInt32 = 3
IEEE1394_API_SET_LOCAL_NODE_PROPERTIES: UInt32 = 4
IEEE1394_REQUEST_FLAG_UNICODE: UInt32 = 1
IEEE1394_REQUEST_FLAG_PERSISTENT: UInt32 = 2
IEEE1394_REQUEST_FLAG_USE_LOCAL_HOST_EUI: UInt32 = 4
IEEE1394API_NOTIFICATION_DEVICE_ACCESS: UInt32 = 1
IEEE1394API_NOTIFICATION_BUS_RESET: UInt32 = 2
IEEE1394API_DEVICE_OWNERSHIP_LOCAL_NODE: UInt32 = 1
IEEE1394API_RESOURCE_OWNERSHIP_LOCAL_NODE: UInt32 = 2
IEEE1394API_DEVICE_OWNERSHIP_REMOTE_NODE: UInt32 = 4
IEEE1394API_RESOURCE_OWNERSHIP_REMOTE_NODE: UInt32 = 8
IEEE1394API_ACCESS_SHARED_READ: UInt32 = 16
IEEE1394API_ACCESS_SHARED_WRITE: UInt32 = 32
IEEE1394API_ACCESS_EXCLUSIVE: UInt32 = 64
IEEE1394API_REMOTE_ACCESS_TRANSFER_REQUEST: UInt32 = 1
IEEE1394API_BUS_RESET_LOCAL_NODE_IS_ROOT: UInt32 = 1
IEEE1394API_BUS_RESET_LOCAL_NODE_IS_IRM: UInt32 = 2
IEEE1394API_BUS_RESET_LOCAL_NODE_INITIATED: UInt32 = 4
class IEEE1394_API_REQUEST(Structure):
    RequestNumber: UInt32
    Flags: UInt32
    u: _u_e__Union
    class _u_e__Union(Union):
        AddVirtualDevice: win32more.Windows.Win32.Devices.IEEE1394_VDEV_PNP_REQUEST
        RemoveVirtualDevice: win32more.Windows.Win32.Devices.IEEE1394_VDEV_PNP_REQUEST
class IEEE1394_VDEV_PNP_REQUEST(Structure):
    fulFlags: UInt32
    Reserved: UInt32
    InstanceId: UInt64
    DeviceId: Byte


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Devices.Cdrom
import win32more.Windows.Win32.Foundation
IOCTL_CDROM_BASE: Int32 = 2
IOCTL_CDROM_UNLOAD_DRIVER: UInt32 = 151560
IOCTL_CDROM_READ_TOC: UInt32 = 147456
IOCTL_CDROM_SEEK_AUDIO_MSF: UInt32 = 147460
IOCTL_CDROM_STOP_AUDIO: UInt32 = 147464
IOCTL_CDROM_PAUSE_AUDIO: UInt32 = 147468
IOCTL_CDROM_RESUME_AUDIO: UInt32 = 147472
IOCTL_CDROM_GET_VOLUME: UInt32 = 147476
IOCTL_CDROM_PLAY_AUDIO_MSF: UInt32 = 147480
IOCTL_CDROM_SET_VOLUME: UInt32 = 147496
IOCTL_CDROM_READ_Q_CHANNEL: UInt32 = 147500
IOCTL_CDROM_GET_CONTROL: UInt32 = 147508
OBSOLETE_IOCTL_CDROM_GET_CONTROL: UInt32 = 147508
IOCTL_CDROM_GET_LAST_SESSION: UInt32 = 147512
IOCTL_CDROM_RAW_READ: UInt32 = 147518
IOCTL_CDROM_DISK_TYPE: UInt32 = 131136
IOCTL_CDROM_GET_DRIVE_GEOMETRY: UInt32 = 147532
IOCTL_CDROM_GET_DRIVE_GEOMETRY_EX: UInt32 = 147536
IOCTL_CDROM_READ_TOC_EX: UInt32 = 147540
IOCTL_CDROM_GET_CONFIGURATION: UInt32 = 147544
IOCTL_CDROM_EXCLUSIVE_ACCESS: UInt32 = 180316
IOCTL_CDROM_SET_SPEED: UInt32 = 147552
IOCTL_CDROM_GET_INQUIRY_DATA: UInt32 = 147556
IOCTL_CDROM_ENABLE_STREAMING: UInt32 = 147560
IOCTL_CDROM_SEND_OPC_INFORMATION: UInt32 = 180332
IOCTL_CDROM_GET_PERFORMANCE: UInt32 = 147568
IOCTL_CDROM_CHECK_VERIFY: UInt32 = 149504
IOCTL_CDROM_MEDIA_REMOVAL: UInt32 = 149508
IOCTL_CDROM_EJECT_MEDIA: UInt32 = 149512
IOCTL_CDROM_LOAD_MEDIA: UInt32 = 149516
IOCTL_CDROM_RESERVE: UInt32 = 149520
IOCTL_CDROM_RELEASE: UInt32 = 149524
IOCTL_CDROM_FIND_NEW_DEVICES: UInt32 = 149528
MINIMUM_CDROM_INQUIRY_SIZE: UInt32 = 36
MAXIMUM_CDROM_INQUIRY_SIZE: UInt32 = 260
IOCTL_CDROM_SIMBAD: UInt32 = 147468
MAXIMUM_NUMBER_TRACKS: UInt32 = 100
MAXIMUM_CDROM_SIZE: UInt32 = 804
MINIMUM_CDROM_READ_TOC_EX_SIZE: UInt32 = 2
CDROM_READ_TOC_EX_FORMAT_TOC: UInt32 = 0
CDROM_READ_TOC_EX_FORMAT_SESSION: UInt32 = 1
CDROM_READ_TOC_EX_FORMAT_FULL_TOC: UInt32 = 2
CDROM_READ_TOC_EX_FORMAT_PMA: UInt32 = 3
CDROM_READ_TOC_EX_FORMAT_ATIP: UInt32 = 4
CDROM_READ_TOC_EX_FORMAT_CDTEXT: UInt32 = 5
CDROM_CD_TEXT_PACK_ALBUM_NAME: UInt32 = 128
CDROM_CD_TEXT_PACK_PERFORMER: UInt32 = 129
CDROM_CD_TEXT_PACK_SONGWRITER: UInt32 = 130
CDROM_CD_TEXT_PACK_COMPOSER: UInt32 = 131
CDROM_CD_TEXT_PACK_ARRANGER: UInt32 = 132
CDROM_CD_TEXT_PACK_MESSAGES: UInt32 = 133
CDROM_CD_TEXT_PACK_DISC_ID: UInt32 = 134
CDROM_CD_TEXT_PACK_GENRE: UInt32 = 135
CDROM_CD_TEXT_PACK_TOC_INFO: UInt32 = 136
CDROM_CD_TEXT_PACK_TOC_INFO2: UInt32 = 137
CDROM_CD_TEXT_PACK_UPC_EAN: UInt32 = 142
CDROM_CD_TEXT_PACK_SIZE_INFO: UInt32 = 143
CDROM_DISK_AUDIO_TRACK: UInt32 = 1
CDROM_DISK_DATA_TRACK: UInt32 = 2
IOCTL_CDROM_SUB_Q_CHANNEL: UInt32 = 0
IOCTL_CDROM_CURRENT_POSITION: UInt32 = 1
IOCTL_CDROM_MEDIA_CATALOG: UInt32 = 2
IOCTL_CDROM_TRACK_ISRC: UInt32 = 3
AUDIO_STATUS_NOT_SUPPORTED: UInt32 = 0
AUDIO_STATUS_IN_PROGRESS: UInt32 = 17
AUDIO_STATUS_PAUSED: UInt32 = 18
AUDIO_STATUS_PLAY_COMPLETE: UInt32 = 19
AUDIO_STATUS_PLAY_ERROR: UInt32 = 20
AUDIO_STATUS_NO_STATUS: UInt32 = 21
ADR_NO_MODE_INFORMATION: UInt32 = 0
ADR_ENCODES_CURRENT_POSITION: UInt32 = 1
ADR_ENCODES_MEDIA_CATALOG: UInt32 = 2
ADR_ENCODES_ISRC: UInt32 = 3
AUDIO_WITH_PREEMPHASIS: UInt32 = 1
DIGITAL_COPY_PERMITTED: UInt32 = 2
AUDIO_DATA_TRACK: UInt32 = 4
TWO_FOUR_CHANNEL_AUDIO: UInt32 = 8
CD_RAW_READ_C2_SIZE: UInt32 = 296
CD_RAW_READ_SUBCODE_SIZE: UInt32 = 96
CD_RAW_SECTOR_WITH_C2_SIZE: UInt32 = 2648
CD_RAW_SECTOR_WITH_SUBCODE_SIZE: UInt32 = 2448
CDROM_EXCLUSIVE_CALLER_LENGTH: UInt32 = 64
CDROM_LOCK_IGNORE_VOLUME: UInt32 = 1
CDROM_NO_MEDIA_NOTIFICATIONS: UInt32 = 2
CDROM_NOT_IN_EXCLUSIVE_MODE: UInt32 = 0
CDROM_IN_EXCLUSIVE_MODE: UInt32 = 1
class CDROM_DISK_DATA(Structure):
    DiskData: UInt32
class CDROM_EXCEPTION_PERFORMANCE_DESCRIPTOR(Structure):
    Lba: Byte * 4
    Time: Byte * 2
class CDROM_EXCLUSIVE_ACCESS(Structure):
    RequestType: win32more.Windows.Win32.Devices.Cdrom.EXCLUSIVE_ACCESS_REQUEST_TYPE
    Flags: UInt32
class CDROM_EXCLUSIVE_LOCK(Structure):
    Access: win32more.Windows.Win32.Devices.Cdrom.CDROM_EXCLUSIVE_ACCESS
    CallerName: Byte * 64
class CDROM_EXCLUSIVE_LOCK_STATE(Structure):
    LockState: win32more.Windows.Win32.Foundation.BOOLEAN
    CallerName: Byte * 64
class CDROM_NOMINAL_PERFORMANCE_DESCRIPTOR(Structure):
    StartLba: Byte * 4
    StartPerformance: Byte * 4
    EndLba: Byte * 4
    EndPerformance: Byte * 4
CDROM_OPC_INFO_TYPE = Int32
SimpleOpcInfo: win32more.Windows.Win32.Devices.Cdrom.CDROM_OPC_INFO_TYPE = 1
CDROM_PERFORMANCE_EXCEPTION_TYPE = Int32
CdromNominalPerformance: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_EXCEPTION_TYPE = 1
CdromEntirePerformanceList: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_EXCEPTION_TYPE = 2
CdromPerformanceExceptionsOnly: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_EXCEPTION_TYPE = 3
class CDROM_PERFORMANCE_HEADER(Structure):
    DataLength: Byte * 4
    Except: Annotated[Byte, 1]
    Write: Annotated[Byte, 1]
    Reserved1: Annotated[Byte, 6]
    Reserved2: Byte * 3
    Data: Byte * 1
class CDROM_PERFORMANCE_REQUEST(Structure):
    RequestType: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_REQUEST_TYPE
    PerformanceType: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_TYPE
    Exceptions: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_EXCEPTION_TYPE
    Tolerance: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_TOLERANCE_TYPE
    StaringLba: UInt32
CDROM_PERFORMANCE_REQUEST_TYPE = Int32
CdromPerformanceRequest: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_REQUEST_TYPE = 1
CdromWriteSpeedRequest: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_REQUEST_TYPE = 2
CDROM_PERFORMANCE_TOLERANCE_TYPE = Int32
Cdrom10Nominal20Exceptions: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_TOLERANCE_TYPE = 1
CDROM_PERFORMANCE_TYPE = Int32
CdromReadPerformance: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_TYPE = 1
CdromWritePerformance: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_TYPE = 2
class CDROM_PLAY_AUDIO_MSF(Structure):
    StartingM: Byte
    StartingS: Byte
    StartingF: Byte
    EndingM: Byte
    EndingS: Byte
    EndingF: Byte
class CDROM_READ_TOC_EX(Structure):
    Format: Annotated[Byte, 4]
    Reserved1: Annotated[Byte, 3]
    Msf: Annotated[Byte, 1]
    SessionTrack: Byte
    Reserved2: Byte
    Reserved3: Byte
class CDROM_SEEK_AUDIO_MSF(Structure):
    M: Byte
    S: Byte
    F: Byte
class CDROM_SET_SPEED(Structure):
    RequestType: win32more.Windows.Win32.Devices.Cdrom.CDROM_SPEED_REQUEST
    ReadSpeed: UInt16
    WriteSpeed: UInt16
    RotationControl: win32more.Windows.Win32.Devices.Cdrom.WRITE_ROTATION
class CDROM_SET_STREAMING(Structure):
    RequestType: win32more.Windows.Win32.Devices.Cdrom.CDROM_SPEED_REQUEST
    ReadSize: UInt32
    ReadTime: UInt32
    WriteSize: UInt32
    WriteTime: UInt32
    StartLba: UInt32
    EndLba: UInt32
    RotationControl: win32more.Windows.Win32.Devices.Cdrom.WRITE_ROTATION
    RestoreDefaults: win32more.Windows.Win32.Foundation.BOOLEAN
    SetExact: win32more.Windows.Win32.Foundation.BOOLEAN
    RandomAccess: win32more.Windows.Win32.Foundation.BOOLEAN
    Persistent: win32more.Windows.Win32.Foundation.BOOLEAN
class CDROM_SIMPLE_OPC_INFO(Structure):
    RequestType: win32more.Windows.Win32.Devices.Cdrom.CDROM_OPC_INFO_TYPE
    Exclude0: win32more.Windows.Win32.Foundation.BOOLEAN
    Exclude1: win32more.Windows.Win32.Foundation.BOOLEAN
CDROM_SPEED_REQUEST = Int32
CdromSetSpeed: win32more.Windows.Win32.Devices.Cdrom.CDROM_SPEED_REQUEST = 0
CdromSetStreaming: win32more.Windows.Win32.Devices.Cdrom.CDROM_SPEED_REQUEST = 1
class CDROM_STREAMING_CONTROL(Structure):
    RequestType: win32more.Windows.Win32.Devices.Cdrom.STREAMING_CONTROL_REQUEST_TYPE
class CDROM_SUB_Q_DATA_FORMAT(Structure):
    Format: Byte
    Track: Byte
class CDROM_TOC(Structure):
    Length: Byte * 2
    FirstTrack: Byte
    LastTrack: Byte
    TrackData: win32more.Windows.Win32.Devices.Cdrom.TRACK_DATA * 100
class CDROM_TOC_ATIP_DATA(Structure):
    Length: Byte * 2
    Reserved1: Byte
    Reserved2: Byte
    Descriptors: win32more.Windows.Win32.Devices.Cdrom.CDROM_TOC_ATIP_DATA_BLOCK * 1
class CDROM_TOC_ATIP_DATA_BLOCK(Structure):
    CdrwReferenceSpeed: Annotated[Byte, 3]
    Reserved3: Annotated[Byte, 1]
    WritePower: Annotated[Byte, 3]
    True1: Annotated[Byte, 1]
    Reserved4: Annotated[Byte, 6]
    UnrestrictedUse: Annotated[Byte, 1]
    Reserved5: Annotated[Byte, 1]
    A3Valid: Annotated[Byte, 1]
    A2Valid: Annotated[Byte, 1]
    A1Valid: Annotated[Byte, 1]
    DiscSubType: Annotated[Byte, 3]
    IsCdrw: Annotated[Byte, 1]
    True2: Annotated[Byte, 1]
    Reserved7: Byte
    LeadInMsf: Byte * 3
    Reserved8: Byte
    LeadOutMsf: Byte * 3
    Reserved9: Byte
    A1Values: Byte * 3
    Reserved10: Byte
    A2Values: Byte * 3
    Reserved11: Byte
    A3Values: Byte * 3
    Reserved12: Byte
class CDROM_TOC_CD_TEXT_DATA(Structure):
    Length: Byte * 2
    Reserved1: Byte
    Reserved2: Byte
    Descriptors: win32more.Windows.Win32.Devices.Cdrom.CDROM_TOC_CD_TEXT_DATA_BLOCK * 1
class CDROM_TOC_CD_TEXT_DATA_BLOCK(Structure):
    PackType: Byte
    TrackNumber: Annotated[Byte, 7]
    ExtensionFlag: Annotated[Byte, 1]
    SequenceNumber: Byte
    CharacterPosition: Annotated[Byte, 4]
    BlockNumber: Annotated[Byte, 3]
    Unicode: Annotated[Byte, 1]
    Anonymous: _Anonymous_e__Union
    CRC: Byte * 2
    class _Anonymous_e__Union(Union):
        Text: Byte * 12
        WText: Char * 6
class CDROM_TOC_FULL_TOC_DATA(Structure):
    Length: Byte * 2
    FirstCompleteSession: Byte
    LastCompleteSession: Byte
    Descriptors: win32more.Windows.Win32.Devices.Cdrom.CDROM_TOC_FULL_TOC_DATA_BLOCK * 1
class CDROM_TOC_FULL_TOC_DATA_BLOCK(Structure):
    SessionNumber: Byte
    Control: Annotated[Byte, 4]
    Adr: Annotated[Byte, 4]
    Reserved1: Byte
    Point: Byte
    MsfExtra: Byte * 3
    Zero: Byte
    Msf: Byte * 3
class CDROM_TOC_PMA_DATA(Structure):
    Length: Byte * 2
    Reserved1: Byte
    Reserved2: Byte
    Descriptors: win32more.Windows.Win32.Devices.Cdrom.CDROM_TOC_FULL_TOC_DATA_BLOCK * 1
class CDROM_TOC_SESSION_DATA(Structure):
    Length: Byte * 2
    FirstCompleteSession: Byte
    LastCompleteSession: Byte
    TrackData: win32more.Windows.Win32.Devices.Cdrom.TRACK_DATA * 1
class CDROM_WRITE_SPEED_DESCRIPTOR(Structure):
    MixedReadWrite: Annotated[Byte, 1]
    Exact: Annotated[Byte, 1]
    Reserved1: Annotated[Byte, 1]
    WriteRotationControl: Annotated[Byte, 2]
    Reserved2: Annotated[Byte, 3]
    Reserved3: Byte * 3
    EndLba: Byte * 4
    ReadSpeed: Byte * 4
    WriteSpeed: Byte * 4
class CDROM_WRITE_SPEED_REQUEST(Structure):
    RequestType: win32more.Windows.Win32.Devices.Cdrom.CDROM_PERFORMANCE_REQUEST_TYPE
EXCLUSIVE_ACCESS_REQUEST_TYPE = Int32
ExclusiveAccessQueryState: win32more.Windows.Win32.Devices.Cdrom.EXCLUSIVE_ACCESS_REQUEST_TYPE = 0
ExclusiveAccessLockDevice: win32more.Windows.Win32.Devices.Cdrom.EXCLUSIVE_ACCESS_REQUEST_TYPE = 1
ExclusiveAccessUnlockDevice: win32more.Windows.Win32.Devices.Cdrom.EXCLUSIVE_ACCESS_REQUEST_TYPE = 2
MEDIA_BLANK_TYPE = Int32
MediaBlankTypeFull: win32more.Windows.Win32.Devices.Cdrom.MEDIA_BLANK_TYPE = 0
MediaBlankTypeMinimal: win32more.Windows.Win32.Devices.Cdrom.MEDIA_BLANK_TYPE = 1
MediaBlankTypeIncompleteTrack: win32more.Windows.Win32.Devices.Cdrom.MEDIA_BLANK_TYPE = 2
MediaBlankTypeUnreserveLastTrack: win32more.Windows.Win32.Devices.Cdrom.MEDIA_BLANK_TYPE = 3
MediaBlankTypeTrackTail: win32more.Windows.Win32.Devices.Cdrom.MEDIA_BLANK_TYPE = 4
MediaBlankTypeUncloseLastSession: win32more.Windows.Win32.Devices.Cdrom.MEDIA_BLANK_TYPE = 5
MediaBlankTypeEraseLastSession: win32more.Windows.Win32.Devices.Cdrom.MEDIA_BLANK_TYPE = 6
class RAW_READ_INFO(Structure):
    DiskOffset: Int64
    SectorCount: UInt32
    TrackMode: win32more.Windows.Win32.Devices.Cdrom.TRACK_MODE_TYPE
STREAMING_CONTROL_REQUEST_TYPE = Int32
CdromStreamingDisable: win32more.Windows.Win32.Devices.Cdrom.STREAMING_CONTROL_REQUEST_TYPE = 1
CdromStreamingEnableForReadOnly: win32more.Windows.Win32.Devices.Cdrom.STREAMING_CONTROL_REQUEST_TYPE = 2
CdromStreamingEnableForWriteOnly: win32more.Windows.Win32.Devices.Cdrom.STREAMING_CONTROL_REQUEST_TYPE = 3
CdromStreamingEnableForReadWrite: win32more.Windows.Win32.Devices.Cdrom.STREAMING_CONTROL_REQUEST_TYPE = 4
class SUB_Q_CHANNEL_DATA(Union):
    CurrentPosition: win32more.Windows.Win32.Devices.Cdrom.SUB_Q_CURRENT_POSITION
    MediaCatalog: win32more.Windows.Win32.Devices.Cdrom.SUB_Q_MEDIA_CATALOG_NUMBER
    TrackIsrc: win32more.Windows.Win32.Devices.Cdrom.SUB_Q_TRACK_ISRC
class SUB_Q_CURRENT_POSITION(Structure):
    Header: win32more.Windows.Win32.Devices.Cdrom.SUB_Q_HEADER
    FormatCode: Byte
    Control: Annotated[Byte, 4]
    ADR: Annotated[Byte, 4]
    TrackNumber: Byte
    IndexNumber: Byte
    AbsoluteAddress: Byte * 4
    TrackRelativeAddress: Byte * 4
class SUB_Q_HEADER(Structure):
    Reserved: Byte
    AudioStatus: Byte
    DataLength: Byte * 2
class SUB_Q_MEDIA_CATALOG_NUMBER(Structure):
    Header: win32more.Windows.Win32.Devices.Cdrom.SUB_Q_HEADER
    FormatCode: Byte
    Reserved: Byte * 3
    Reserved1: Annotated[Byte, 7]
    Mcval: Annotated[Byte, 1]
    MediaCatalog: Byte * 15
class SUB_Q_TRACK_ISRC(Structure):
    Header: win32more.Windows.Win32.Devices.Cdrom.SUB_Q_HEADER
    FormatCode: Byte
    Reserved0: Byte
    Track: Byte
    Reserved1: Byte
    Reserved2: Annotated[Byte, 7]
    Tcval: Annotated[Byte, 1]
    TrackIsrc: Byte * 15
class TRACK_DATA(Structure):
    Reserved: Byte
    Control: Annotated[Byte, 4]
    Adr: Annotated[Byte, 4]
    TrackNumber: Byte
    Reserved1: Byte
    Address: Byte * 4
TRACK_MODE_TYPE = Int32
YellowMode2: win32more.Windows.Win32.Devices.Cdrom.TRACK_MODE_TYPE = 0
XAForm2: win32more.Windows.Win32.Devices.Cdrom.TRACK_MODE_TYPE = 1
CDDA: win32more.Windows.Win32.Devices.Cdrom.TRACK_MODE_TYPE = 2
RawWithC2AndSubCode: win32more.Windows.Win32.Devices.Cdrom.TRACK_MODE_TYPE = 3
RawWithC2: win32more.Windows.Win32.Devices.Cdrom.TRACK_MODE_TYPE = 4
RawWithSubCode: win32more.Windows.Win32.Devices.Cdrom.TRACK_MODE_TYPE = 5
class VOLUME_CONTROL(Structure):
    PortVolume: Byte * 4
WRITE_ROTATION = Int32
CdromDefaultRotation: win32more.Windows.Win32.Devices.Cdrom.WRITE_ROTATION = 0
CdromCAVRotation: win32more.Windows.Win32.Devices.Cdrom.WRITE_ROTATION = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Media
import win32more.Windows.Media.Core
import win32more.Windows.Media.SpeechSynthesis
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class IInstalledVoicesStatic(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechSynthesis.IInstalledVoicesStatic'
    _iid_ = Guid('{7d526ecc-7533-4c3f-85be-888c2baeebdc}')
    @winrt_commethod(6)
    def get_AllVoices(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.SpeechSynthesis.VoiceInformation]: ...
    @winrt_commethod(7)
    def get_DefaultVoice(self) -> win32more.Windows.Media.SpeechSynthesis.VoiceInformation: ...
    AllVoices = property(get_AllVoices, None)
    DefaultVoice = property(get_DefaultVoice, None)
class IInstalledVoicesStatic2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechSynthesis.IInstalledVoicesStatic2'
    _iid_ = Guid('{64255f2e-358d-4058-be9a-fd3fcb423530}')
    @winrt_commethod(6)
    def TrySetDefaultVoiceAsync(self, voice: win32more.Windows.Media.SpeechSynthesis.VoiceInformation) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class ISpeechSynthesisStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Media.SpeechSynthesis.ISpeechSynthesisStream'
    _iid_ = Guid('{83e46e93-244c-4622-ba0b-6229c4d0d65d}')
    @winrt_commethod(6)
    def get_Markers(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.IMediaMarker]: ...
    Markers = property(get_Markers, None)
class ISpeechSynthesizer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechSynthesis.ISpeechSynthesizer'
    _iid_ = Guid('{ce9f7c76-97f4-4ced-ad68-d51c458e45c6}')
    @winrt_commethod(6)
    def SynthesizeTextToStreamAsync(self, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechSynthesis.SpeechSynthesisStream]: ...
    @winrt_commethod(7)
    def SynthesizeSsmlToStreamAsync(self, Ssml: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechSynthesis.SpeechSynthesisStream]: ...
    @winrt_commethod(8)
    def put_Voice(self, value: win32more.Windows.Media.SpeechSynthesis.VoiceInformation) -> Void: ...
    @winrt_commethod(9)
    def get_Voice(self) -> win32more.Windows.Media.SpeechSynthesis.VoiceInformation: ...
    Voice = property(get_Voice, put_Voice)
class ISpeechSynthesizer2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechSynthesis.ISpeechSynthesizer2'
    _iid_ = Guid('{a7c5ecb2-4339-4d6a-bbf8-c7a4f1544c2e}')
    @winrt_commethod(6)
    def get_Options(self) -> win32more.Windows.Media.SpeechSynthesis.SpeechSynthesizerOptions: ...
    Options = property(get_Options, None)
class ISpeechSynthesizerOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions'
    _iid_ = Guid('{a0e23871-cc3d-43c9-91b1-ee185324d83d}')
    @winrt_commethod(6)
    def get_IncludeWordBoundaryMetadata(self) -> Boolean: ...
    @winrt_commethod(7)
    def put_IncludeWordBoundaryMetadata(self, value: Boolean) -> Void: ...
    @winrt_commethod(8)
    def get_IncludeSentenceBoundaryMetadata(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_IncludeSentenceBoundaryMetadata(self, value: Boolean) -> Void: ...
    IncludeSentenceBoundaryMetadata = property(get_IncludeSentenceBoundaryMetadata, put_IncludeSentenceBoundaryMetadata)
    IncludeWordBoundaryMetadata = property(get_IncludeWordBoundaryMetadata, put_IncludeWordBoundaryMetadata)
class ISpeechSynthesizerOptions2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions2'
    _iid_ = Guid('{1cbef60e-119c-4bed-b118-d250c3a25793}')
    @winrt_commethod(6)
    def get_AudioVolume(self) -> Double: ...
    @winrt_commethod(7)
    def put_AudioVolume(self, value: Double) -> Void: ...
    @winrt_commethod(8)
    def get_SpeakingRate(self) -> Double: ...
    @winrt_commethod(9)
    def put_SpeakingRate(self, value: Double) -> Void: ...
    @winrt_commethod(10)
    def get_AudioPitch(self) -> Double: ...
    @winrt_commethod(11)
    def put_AudioPitch(self, value: Double) -> Void: ...
    AudioPitch = property(get_AudioPitch, put_AudioPitch)
    AudioVolume = property(get_AudioVolume, put_AudioVolume)
    SpeakingRate = property(get_SpeakingRate, put_SpeakingRate)
class ISpeechSynthesizerOptions3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions3'
    _iid_ = Guid('{401ed877-902c-4814-a582-a5d0c0769fa8}')
    @winrt_commethod(6)
    def get_AppendedSilence(self) -> win32more.Windows.Media.SpeechSynthesis.SpeechAppendedSilence: ...
    @winrt_commethod(7)
    def put_AppendedSilence(self, value: win32more.Windows.Media.SpeechSynthesis.SpeechAppendedSilence) -> Void: ...
    @winrt_commethod(8)
    def get_PunctuationSilence(self) -> win32more.Windows.Media.SpeechSynthesis.SpeechPunctuationSilence: ...
    @winrt_commethod(9)
    def put_PunctuationSilence(self, value: win32more.Windows.Media.SpeechSynthesis.SpeechPunctuationSilence) -> Void: ...
    AppendedSilence = property(get_AppendedSilence, put_AppendedSilence)
    PunctuationSilence = property(get_PunctuationSilence, put_PunctuationSilence)
class IVoiceInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.SpeechSynthesis.IVoiceInformation'
    _iid_ = Guid('{b127d6a4-1291-4604-aa9c-83134083352c}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Language(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_Description(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_Gender(self) -> win32more.Windows.Media.SpeechSynthesis.VoiceGender: ...
    Description = property(get_Description, None)
    DisplayName = property(get_DisplayName, None)
    Gender = property(get_Gender, None)
    Id = property(get_Id, None)
    Language = property(get_Language, None)
class SpeechAppendedSilence(Enum, Int32):
    Default = 0
    Min = 1
class SpeechPunctuationSilence(Enum, Int32):
    Default = 0
    Min = 1
class SpeechSynthesisStream(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesisStream
    _classid_ = 'Windows.Media.SpeechSynthesis.SpeechSynthesisStream'
    @winrt_mixinmethod
    def get_Markers(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesisStream) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.IMediaMarker]: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def put_Size(self: win32more.Windows.Storage.Streams.IRandomAccessStream, value: UInt64) -> Void: ...
    @winrt_mixinmethod
    def GetInputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IInputStream: ...
    @winrt_mixinmethod
    def GetOutputStreamAt(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> win32more.Windows.Storage.Streams.IOutputStream: ...
    @winrt_mixinmethod
    def get_Position(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> UInt64: ...
    @winrt_mixinmethod
    def Seek(self: win32more.Windows.Storage.Streams.IRandomAccessStream, position: UInt64) -> Void: ...
    @winrt_mixinmethod
    def CloneStream(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> win32more.Windows.Storage.Streams.IRandomAccessStream: ...
    @winrt_mixinmethod
    def get_CanRead(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def get_CanWrite(self: win32more.Windows.Storage.Streams.IRandomAccessStream) -> Boolean: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def ReadAsync(self: win32more.Windows.Storage.Streams.IInputStream, buffer: win32more.Windows.Storage.Streams.IBuffer, count: UInt32, options: win32more.Windows.Storage.Streams.InputStreamOptions) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[win32more.Windows.Storage.Streams.IBuffer, UInt32]: ...
    @winrt_mixinmethod
    def WriteAsync(self: win32more.Windows.Storage.Streams.IOutputStream, buffer: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncOperationWithProgress[UInt32, UInt32]: ...
    @winrt_mixinmethod
    def FlushAsync(self: win32more.Windows.Storage.Streams.IOutputStream) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def get_ContentType(self: win32more.Windows.Storage.Streams.IContentTypeProvider) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_TimedMetadataTracks(self: win32more.Windows.Media.Core.ITimedMetadataTrackProvider) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Core.TimedMetadataTrack]: ...
    CanRead = property(get_CanRead, None)
    CanWrite = property(get_CanWrite, None)
    ContentType = property(get_ContentType, None)
    Markers = property(get_Markers, None)
    Position = property(get_Position, None)
    Size = property(get_Size, put_Size)
    TimedMetadataTracks = property(get_TimedMetadataTracks, None)
class _SpeechSynthesizer_Meta_(ComPtr.__class__):
    pass
class SpeechSynthesizer(ComPtr, metaclass=_SpeechSynthesizer_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizer
    _classid_ = 'Windows.Media.SpeechSynthesis.SpeechSynthesizer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Media.SpeechSynthesis.SpeechSynthesizer.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Media.SpeechSynthesis.SpeechSynthesizer: ...
    @winrt_mixinmethod
    def SynthesizeTextToStreamAsync(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizer, text: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechSynthesis.SpeechSynthesisStream]: ...
    @winrt_mixinmethod
    def SynthesizeSsmlToStreamAsync(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizer, Ssml: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.SpeechSynthesis.SpeechSynthesisStream]: ...
    @winrt_mixinmethod
    def put_Voice(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizer, value: win32more.Windows.Media.SpeechSynthesis.VoiceInformation) -> Void: ...
    @winrt_mixinmethod
    def get_Voice(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizer) -> win32more.Windows.Media.SpeechSynthesis.VoiceInformation: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def get_Options(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizer2) -> win32more.Windows.Media.SpeechSynthesis.SpeechSynthesizerOptions: ...
    @winrt_classmethod
    def TrySetDefaultVoiceAsync(cls: win32more.Windows.Media.SpeechSynthesis.IInstalledVoicesStatic2, voice: win32more.Windows.Media.SpeechSynthesis.VoiceInformation) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_classmethod
    def get_AllVoices(cls: win32more.Windows.Media.SpeechSynthesis.IInstalledVoicesStatic) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.SpeechSynthesis.VoiceInformation]: ...
    @winrt_classmethod
    def get_DefaultVoice(cls: win32more.Windows.Media.SpeechSynthesis.IInstalledVoicesStatic) -> win32more.Windows.Media.SpeechSynthesis.VoiceInformation: ...
    Options = property(get_Options, None)
    Voice = property(get_Voice, put_Voice)
    _SpeechSynthesizer_Meta_.AllVoices = property(get_AllVoices, None)
    _SpeechSynthesizer_Meta_.DefaultVoice = property(get_DefaultVoice, None)
class SpeechSynthesizerOptions(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions
    _classid_ = 'Windows.Media.SpeechSynthesis.SpeechSynthesizerOptions'
    @winrt_mixinmethod
    def get_IncludeWordBoundaryMetadata(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IncludeWordBoundaryMetadata(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_IncludeSentenceBoundaryMetadata(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions) -> Boolean: ...
    @winrt_mixinmethod
    def put_IncludeSentenceBoundaryMetadata(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_AudioVolume(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions2) -> Double: ...
    @winrt_mixinmethod
    def put_AudioVolume(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions2, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_SpeakingRate(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions2) -> Double: ...
    @winrt_mixinmethod
    def put_SpeakingRate(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions2, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_AudioPitch(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions2) -> Double: ...
    @winrt_mixinmethod
    def put_AudioPitch(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions2, value: Double) -> Void: ...
    @winrt_mixinmethod
    def get_AppendedSilence(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions3) -> win32more.Windows.Media.SpeechSynthesis.SpeechAppendedSilence: ...
    @winrt_mixinmethod
    def put_AppendedSilence(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions3, value: win32more.Windows.Media.SpeechSynthesis.SpeechAppendedSilence) -> Void: ...
    @winrt_mixinmethod
    def get_PunctuationSilence(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions3) -> win32more.Windows.Media.SpeechSynthesis.SpeechPunctuationSilence: ...
    @winrt_mixinmethod
    def put_PunctuationSilence(self: win32more.Windows.Media.SpeechSynthesis.ISpeechSynthesizerOptions3, value: win32more.Windows.Media.SpeechSynthesis.SpeechPunctuationSilence) -> Void: ...
    AppendedSilence = property(get_AppendedSilence, put_AppendedSilence)
    AudioPitch = property(get_AudioPitch, put_AudioPitch)
    AudioVolume = property(get_AudioVolume, put_AudioVolume)
    IncludeSentenceBoundaryMetadata = property(get_IncludeSentenceBoundaryMetadata, put_IncludeSentenceBoundaryMetadata)
    IncludeWordBoundaryMetadata = property(get_IncludeWordBoundaryMetadata, put_IncludeWordBoundaryMetadata)
    PunctuationSilence = property(get_PunctuationSilence, put_PunctuationSilence)
    SpeakingRate = property(get_SpeakingRate, put_SpeakingRate)
class VoiceGender(Enum, Int32):
    Male = 0
    Female = 1
class VoiceInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.SpeechSynthesis.IVoiceInformation
    _classid_ = 'Windows.Media.SpeechSynthesis.VoiceInformation'
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Media.SpeechSynthesis.IVoiceInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Media.SpeechSynthesis.IVoiceInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Language(self: win32more.Windows.Media.SpeechSynthesis.IVoiceInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Description(self: win32more.Windows.Media.SpeechSynthesis.IVoiceInformation) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Gender(self: win32more.Windows.Media.SpeechSynthesis.IVoiceInformation) -> win32more.Windows.Media.SpeechSynthesis.VoiceGender: ...
    Description = property(get_Description, None)
    DisplayName = property(get_DisplayName, None)
    Gender = property(get_Gender, None)
    Id = property(get_Id, None)
    Language = property(get_Language, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Performance.HardwareCounterProfiling
@winfunctype('KERNEL32.dll')
def EnableThreadProfiling(ThreadHandle: win32more.Windows.Win32.Foundation.HANDLE, Flags: UInt32, HardwareCounters: UInt64, PerformanceDataHandle: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def DisableThreadProfiling(PerformanceDataHandle: win32more.Windows.Win32.Foundation.HANDLE) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def QueryThreadProfiling(ThreadHandle: win32more.Windows.Win32.Foundation.HANDLE, Enabled: POINTER(win32more.Windows.Win32.Foundation.BOOLEAN)) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def ReadThreadProfilingData(PerformanceDataHandle: win32more.Windows.Win32.Foundation.HANDLE, Flags: UInt32, PerformanceData: POINTER(win32more.Windows.Win32.System.Performance.HardwareCounterProfiling.PERFORMANCE_DATA)) -> UInt32: ...
class HARDWARE_COUNTER_DATA(Structure):
    Type: win32more.Windows.Win32.System.Performance.HardwareCounterProfiling.HARDWARE_COUNTER_TYPE
    Reserved: UInt32
    Value: UInt64
HARDWARE_COUNTER_TYPE = Int32
PMCCounter: win32more.Windows.Win32.System.Performance.HardwareCounterProfiling.HARDWARE_COUNTER_TYPE = 0
MaxHardwareCounterType: win32more.Windows.Win32.System.Performance.HardwareCounterProfiling.HARDWARE_COUNTER_TYPE = 1
class PERFORMANCE_DATA(Structure):
    Size: UInt16
    Version: Byte
    HwCountersCount: Byte
    ContextSwitchCount: UInt32
    WaitReasonBitMap: UInt64
    CycleTime: UInt64
    RetryCount: UInt32
    Reserved: UInt32
    HwCounters: win32more.Windows.Win32.System.Performance.HardwareCounterProfiling.HARDWARE_COUNTER_DATA * 16


make_ready(__name__)
